using System;
using System.ComponentModel;
using System.Workflow.ComponentModel.Compiler;

namespace HAGeeks.Premise.WF.Activities
{
    public class BaseValidator : ActivityValidator
    {
        public override ValidationErrorCollection Validate(ValidationManager manager, object obj)
        {
            ValidationErrorCollection errors = base.Validate(manager, obj);
            BaseActivity currentActivity;

            if ((obj != null) && (obj is BaseActivity))
            {
                currentActivity = (BaseActivity) obj;

                // check for valid connection parameters
                // You must have a host
                if (String.IsNullOrEmpty(currentActivity.Host))
                {
                    errors.Add(new ValidationError("You must enter a host server name or IP address.", 100));
                }
                
                // if a userid is specified then a password needs to be added
                if (!String.IsNullOrEmpty(currentActivity.UserId) && String.IsNullOrEmpty(currentActivity.Password))
                {
                    errors.Add(new ValidationError("You must enter a password when you enter a user id.", 101));
                }
                else
                {
                    // if a password is specified then a userid needs to be added
                    if (String.IsNullOrEmpty(currentActivity.UserId) && !String.IsNullOrEmpty(currentActivity.Password))
                    {
                        errors.Add(new ValidationError("You must enter a userid when you enter a password.", 102));
                    }
                }

                // You must have a object name
                if (String.IsNullOrEmpty(currentActivity.ObjectName))
                {
                    errors.Add(new ValidationError("You must enter an object name.", 103));
                }

                // You must have a property name
                if (String.IsNullOrEmpty(currentActivity.PropertyName))
                {
                    errors.Add(new ValidationError("You must enter a property name.", 104));
                }
            }
            else
            {
                throw new ArgumentException("The parameter is null or not of type BaseActivity.", "obj");
            }
            return errors;
        }
    }
}